';
-print '';
+print '
';
print '| | ';
print '';
print '';
@@ -336,6 +320,24 @@ print '';
+print_liste_field_titre($langs->trans("ID"),$_SERVER["PHP_SELF"],"t.rowid","",$param,'',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronLabel"),$_SERVER["PHP_SELF"],"t.label","",$param,'',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronTask"),'','',"",$param,'',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronFrequency"),'',"","",$param,'',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronDtStart"),$_SERVER["PHP_SELF"],"t.datestart","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronDtEnd"),$_SERVER["PHP_SELF"],"t.dateend","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronMaxRun"),$_SERVER["PHP_SELF"],"t.maxrun","",$param,'align="right"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronNbRun"),$_SERVER["PHP_SELF"],"t.nbrun","",$param,'align="right"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronDtNextLaunch"),$_SERVER["PHP_SELF"],"t.datenextrun","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronDtLastLaunch"),$_SERVER["PHP_SELF"],"t.datelastrun","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronLastResult"),$_SERVER["PHP_SELF"],"t.lastresult","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("CronLastOutput"),$_SERVER["PHP_SELF"],"t.lastoutput","",$param,'',$sortfield,$sortorder);
+print_liste_field_titre($langs->trans("Status"),$_SERVER["PHP_SELF"],"t.status","",$param,'align="center"',$sortfield,$sortorder);
+print_liste_field_titre('');
+print " |
\n";
+
+
if ($num > 0)
{
// Loop on each job
diff --git a/htdocs/expensereport/class/expensereport.class.php b/htdocs/expensereport/class/expensereport.class.php
index 578ab81b339..e4754f4ab60 100644
--- a/htdocs/expensereport/class/expensereport.class.php
+++ b/htdocs/expensereport/class/expensereport.class.php
@@ -1913,7 +1913,7 @@ class ExpenseReport extends CommonObject
$response->label=$langs->trans("ExpenseReportsToPay");
$response->url=DOL_URL_ROOT.'/expensereport/list.php?mainmenu=hrm&statut=5';
}
- $response->img=img_object($langs->trans("ExpenseReports"),"trip");
+ $response->img=img_object('',"trip");
while ($obj=$this->db->fetch_object($resql))
{
diff --git a/htdocs/fichinter/apercu.php b/htdocs/fichinter/apercu.php
deleted file mode 100644
index 899ecaf9805..00000000000
--- a/htdocs/fichinter/apercu.php
+++ /dev/null
@@ -1,197 +0,0 @@
-
- * Copyright (C) 2004-2014 Laurent Destailleur
- * Copyright (C) 2005-2011 Regis Houssin
- * Copyright (C) 2011-2012 Juanjo Menent
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see .
- */
-
-/**
- * \file htdocs/fichinter/apercu.php
- * \ingroup fichinter
- * \brief Page de l'onglet apercu d'une fiche d'intervention
- */
-
-require '../main.inc.php';
-require_once DOL_DOCUMENT_ROOT.'/core/lib/fichinter.lib.php';
-require_once DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php';
-require_once DOL_DOCUMENT_ROOT.'/fichinter/class/fichinter.class.php';
-if (! empty($conf->projet->enabled)) require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
-
-$langs->load('interventions');
-
-
-// Security check
-$socid=0;
-$id = GETPOST('id','int');
-$ref = GETPOST('ref','alpha');
-if ($user->societe_id) $socid=$user->societe_id;
-$result = restrictedArea($user, 'ficheinter', $id, 'fichinter');
-
-
-/*
- * View
- */
-
-llxHeader();
-
-$form = new Form($db);
-
-/* *************************************************************************** */
-/* */
-/* Mode fiche */
-/* */
-/* *************************************************************************** */
-
-if ($id > 0 || ! empty($ref))
-{
- $object = new Fichinter($db);
-
- if ($object->fetch($id,$ref) > 0)
- {
- $soc = new Societe($db);
- $soc->fetch($object->socid);
-
- $head = fichinter_prepare_head($object);
- dol_fiche_head($head, 'preview', $langs->trans("InterventionCard"), 0, 'intervention');
-
- /*
- * Fiche intervention
- */
- print '';
-
- $linkback = ''.$langs->trans("BackToList").'';
-
- // Ref
- print '| '.$langs->trans("Ref").' | ';
- print $form->showrefnav($object, 'ref', $linkback, 1, 'ref', 'ref');
- print ' |
';
-
- $nbrow=3;
- // Client
- print "| ".$langs->trans("Customer")." | ";
- print '';
- print ''.$soc->name.'';
- print ' | ';
- print '';
-
- /*
- * Documents
- */
- $objectref = dol_sanitizeFileName($object->ref);
- $dir_output = $conf->ficheinter->dir_output . "/";
- $filepath = $dir_output . $objectref . "/";
- $file = $filepath . $objectref . ".pdf";
- $filedetail = $filepath . $objectref . "-detail.pdf";
- $relativepath = "${objectref}/${objectref}.pdf";
- $relativepathdetail = "${objectref}/${objectref}-detail.pdf";
-
- // Define path to preview pdf file (preview precompiled "file.ext" are "file.ext_preview.png")
- $fileimage = $file.'_preview.png'; // If PDF has 1 page
- $fileimagebis = $file.'_preview-0.pdf.png'; // If PDF has more than one page
- $relativepathimage = $relativepath.'_preview.png';
-
- $var=true;
-
- // Si fichier PDF existe
- if (file_exists($file))
- {
- $encfile = urlencode($file);
- print load_fiche_titre($langs->trans("Documents"));
- print '';
-
- print "| ".$langs->trans("Intervention")." PDF | ";
-
- print ''.$object->ref.'.pdf | ';
- print ''.dol_print_size(dol_filesize($file)).' | ';
- print ''.dol_print_date(dol_filemtime($file),'dayhour').' | ';
- print ' ';
-
- // Si fichier detail PDF existe
- if (file_exists($filedetail))
- {
- print "| Fiche d'intervention detaillee | ";
-
- print ''.$object->ref.'-detail.pdf | ';
- print ''.dol_print_size(dol_filesize($filedetail)).' | ';
- print ''.dol_print_date(dol_filemtime($filedetail),'dayhour').' | ';
- print ' ';
- }
- print " \n";
-
- // Conversion du PDF en image png si fichier png non existant
- if ((! file_exists($fileimage) && ! file_exists($fileimagebis)) || (filemtime($fileimage) < filemtime($file)))
- {
- if (class_exists("Imagick"))
- {
- $ret = dol_convert_file($file,'png',$fileimage);
- if ($ret < 0) $error++;
- }
- else
- {
- $langs->load("errors");
- print ''.$langs->trans("ErrorNoImagickReadimage").'';
- }
- }
- }
-
- print " |
";
-
- // Statut
- print '| '.$langs->trans("Status").' | ';
- print "".$object->getLibStatut(4)." | \n";
- print '
';
-
- // Date
- print '| '.$langs->trans("Date").' | ';
- print "".dol_print_date($object->datec,"daytext")." | \n";
- print '
';
-
- print '
';
-
- dol_fiche_end();
- }
- else
- {
- // Object not found
- print $langs->trans("ErrorFichinterNotFound",$id);
- }
-}
-
-// Si fichier png PDF d'1 page trouve
-if (file_exists($fileimage))
-{
- print '
';
-}
-// Si fichier png PDF de plus d'1 page trouve
-elseif (file_exists($fileimagebis))
-{
- $multiple = $relativepath . "-";
-
- for ($i = 0; $i < 20; $i++)
- {
- $preview = $multiple.$i.'.png';
-
- if (file_exists($dir_output.$preview))
- {
- print '.')
';
- }
- }
-}
-
-
-llxFooter();
-
-$db->close();
diff --git a/htdocs/fichinter/card.php b/htdocs/fichinter/card.php
index 31f72e18075..cd10e704d90 100644
--- a/htdocs/fichinter/card.php
+++ b/htdocs/fichinter/card.php
@@ -1079,7 +1079,7 @@ else if ($id > 0 || ! empty($ref))
$head = fichinter_prepare_head($object);
- dol_fiche_head($head, 'card', $langs->trans("InterventionCard"), 0, 'intervention');
+ dol_fiche_head($head, 'card', $langs->trans("InterventionCard"), -1, 'intervention');
$formconfirm='';
diff --git a/htdocs/fichinter/contact.php b/htdocs/fichinter/contact.php
index 83825b08a90..2b40553a3d9 100644
--- a/htdocs/fichinter/contact.php
+++ b/htdocs/fichinter/contact.php
@@ -122,7 +122,7 @@ if ($id > 0 || ! empty($ref))
$object->fetch_thirdparty();
$head = fichinter_prepare_head($object);
- dol_fiche_head($head, 'contact', $langs->trans("InterventionCard"), 0, 'intervention');
+ dol_fiche_head($head, 'contact', $langs->trans("InterventionCard"), -1, 'intervention');
// Intervention card
diff --git a/htdocs/fichinter/document.php b/htdocs/fichinter/document.php
index 2e53d6ebc62..f24283e8aa1 100644
--- a/htdocs/fichinter/document.php
+++ b/htdocs/fichinter/document.php
@@ -89,7 +89,7 @@ if ($object->id)
$head=fichinter_prepare_head($object);
- dol_fiche_head($head, 'documents', $langs->trans("InterventionCard"), 0, 'intervention');
+ dol_fiche_head($head, 'documents', $langs->trans("InterventionCard"), -1, 'intervention');
// Construit liste des fichiers
diff --git a/htdocs/fichinter/info.php b/htdocs/fichinter/info.php
index de2317eecca..87533644893 100644
--- a/htdocs/fichinter/info.php
+++ b/htdocs/fichinter/info.php
@@ -58,7 +58,7 @@ $object->fetch_thirdparty();
$object->info($object->id);
$head = fichinter_prepare_head($object);
-dol_fiche_head($head, 'info', $langs->trans('InterventionCard'), 0, 'intervention');
+dol_fiche_head($head, 'info', $langs->trans('InterventionCard'), -1, 'intervention');
// Intervention card
$linkback = ''.$langs->trans("BackToList").'';
diff --git a/htdocs/fichinter/note.php b/htdocs/fichinter/note.php
index 1da0b0c425c..43a2654d1fd 100644
--- a/htdocs/fichinter/note.php
+++ b/htdocs/fichinter/note.php
@@ -63,7 +63,7 @@ if ($id > 0 || ! empty($ref))
$object->fetch_thirdparty();
$head = fichinter_prepare_head($object);
- dol_fiche_head($head, 'note', $langs->trans('InterventionCard'), 0, 'intervention');
+ dol_fiche_head($head, 'note', $langs->trans('InterventionCard'), -1, 'intervention');
// Intervention card
$linkback = ''.$langs->trans("BackToList").'';
diff --git a/htdocs/fourn/class/fournisseur.commande.class.php b/htdocs/fourn/class/fournisseur.commande.class.php
index a4deab90768..1da9854791b 100644
--- a/htdocs/fourn/class/fournisseur.commande.class.php
+++ b/htdocs/fourn/class/fournisseur.commande.class.php
@@ -2624,7 +2624,7 @@ class CommandeFournisseur extends CommonOrder
$response->warning_delay=$conf->commande->fournisseur->warning_delay/60/60/24;
$response->label=$langs->trans("SuppliersOrdersToProcess");
$response->url=DOL_URL_ROOT.'/fourn/commande/list.php?statut=1,2,3&mainmenu=commercial&leftmenu=orders_suppliers';
- $response->img=img_object($langs->trans("Orders"),"order");
+ $response->img=img_object('',"order");
while ($obj=$this->db->fetch_object($resql))
{
diff --git a/htdocs/fourn/class/fournisseur.facture.class.php b/htdocs/fourn/class/fournisseur.facture.class.php
index 009f765e5cd..5f435da9daf 100644
--- a/htdocs/fourn/class/fournisseur.facture.class.php
+++ b/htdocs/fourn/class/fournisseur.facture.class.php
@@ -1787,7 +1787,7 @@ class FactureFournisseur extends CommonInvoice
$response->warning_delay=$conf->facture->fournisseur->warning_delay/60/60/24;
$response->label=$langs->trans("SupplierBillsToPay");
$response->url=DOL_URL_ROOT.'/fourn/facture/list.php?filtre=fac.fk_statut:1,paye:0&mainmenu=accountancy&leftmenu=suppliers_bills';
- $response->img=img_object($langs->trans("Bills"),"bill");
+ $response->img=img_object('',"bill");
$facturestatic = new FactureFournisseur($this->db);
diff --git a/htdocs/index.php b/htdocs/index.php
index 943914ebd15..e0609c91274 100644
--- a/htdocs/index.php
+++ b/htdocs/index.php
@@ -561,13 +561,14 @@ if (! empty($valid_dashboardlines))
$boxwork .='
';
$boxwork .= '
';
- $boxwork .= '
'.$board->img.' '.$board->label.'';
+ $boxwork .= '
'.$board->img.' '.$board->label.'';
$boxwork .= '
'.$board->nbtodo.'';
$boxwork .= '
';
if ($board->nbtodolate > 0)
{
$boxwork .= '
'; // End table array of working board
$boxwork.='';
-//print $boxwork;
-
print '';
diff --git a/htdocs/install/mysql/migration/5.0.0-6.0.0.sql b/htdocs/install/mysql/migration/5.0.0-6.0.0.sql
index 25145dc7cfe..6e098e4f59d 100644
--- a/htdocs/install/mysql/migration/5.0.0-6.0.0.sql
+++ b/htdocs/install/mysql/migration/5.0.0-6.0.0.sql
@@ -125,6 +125,9 @@ INSERT INTO llx_const (name, entity, value, type, visible, note) VALUES ('USER_A
ALTER TABLE llx_chargesociales ADD COLUMN ref varchar(16);
ALTER TABLE llx_chargesociales ADD COLUMN fk_projet integer DEFAULT NULL;
+ALTER TABLE llx_cronjob ADD COLUMN processing integer NOT NULL DEFAULT 0;
+
+
create table llx_payment_various
(
rowid integer AUTO_INCREMENT PRIMARY KEY,
@@ -144,3 +147,6 @@ create table llx_payment_various
fk_user_author integer,
fk_user_modif integer
)ENGINE=innodb;
+
+
+
diff --git a/htdocs/install/mysql/tables/llx_cronjob.sql b/htdocs/install/mysql/tables/llx_cronjob.sql
index f9d2ac1ab7a..96458de8420 100644
--- a/htdocs/install/mysql/tables/llx_cronjob.sql
+++ b/htdocs/install/mysql/tables/llx_cronjob.sql
@@ -46,6 +46,7 @@ CREATE TABLE llx_cronjob
nbrun integer, -- nb of run complete (failed or not)
autodelete integer DEFAULT 0, -- 0=Job is kept unchanged once nbrun > maxrun or date > dateend, 2=Job must be archived (archive = status 2) once nbrun > maxrun or date > dateend
status integer NOT NULL DEFAULT 1, -- 0=disabled, 1=enabled, 2=archived
+ processing integer NOT NULL DEFAULT 0, -- 1=process currently running
test varchar(255) DEFAULT '1',
fk_user_author integer DEFAULT NULL,
fk_user_mod integer DEFAULT NULL,
diff --git a/htdocs/main.inc.php b/htdocs/main.inc.php
index 7d5e5dfa64c..8d1138e5758 100644
--- a/htdocs/main.inc.php
+++ b/htdocs/main.inc.php
@@ -848,9 +848,9 @@ if (! defined('NOREQUIRETRAN'))
// Define some constants used for style of arrays
$bc=array(0=>'class="impair"',1=>'class="pair"');
-$bcdd=array(0=>'class="impair drag drop"',1=>'class="pair drag drop"');
-$bcnd=array(0=>'class="impair nodrag nodrop nohover"',1=>'class="pair nodrag nodrop nohoverpair"'); // Used for tr to add new lines
-$bctag=array(0=>'class="impair tagtr"',1=>'class="pair tagtr"');
+$bcdd=array(0=>'class="drag drop"',1=>'class="drag drop"');
+$bcnd=array(0=>'class="nodrag nodrop nohover"',1=>'class="nodrag nodrop nohoverpair"'); // Used for tr to add new lines
+$bctag=array(0=>'class="tagtr"',1=>'class="pair tagtr"');
// Define messages variables
$mesg=''; $warning=''; $error=0;
diff --git a/htdocs/projet/class/project.class.php b/htdocs/projet/class/project.class.php
index eeb10281c3a..7748534c970 100644
--- a/htdocs/projet/class/project.class.php
+++ b/htdocs/projet/class/project.class.php
@@ -1694,7 +1694,7 @@ class Project extends CommonObject
$response->label = $langs->trans("OpenedProjects");
if ($user->rights->projet->all->lire) $response->url = DOL_URL_ROOT.'/projet/list.php?search_status=1&mainmenu=project';
else $response->url = DOL_URL_ROOT.'/projet/list.php?search_project_user=-1&search_status=1&mainmenu=project';
- $response->img = img_object($langs->trans("Projects"),"projectpub");
+ $response->img = img_object('',"projectpub");
// This assignment in condition is not a bug. It allows walking the results.
while ($obj=$this->db->fetch_object($resql))
diff --git a/htdocs/projet/class/task.class.php b/htdocs/projet/class/task.class.php
index 905098d202a..7c986e4d9a2 100644
--- a/htdocs/projet/class/task.class.php
+++ b/htdocs/projet/class/task.class.php
@@ -1713,7 +1713,7 @@ class Task extends CommonObject
$response->label = $langs->trans("OpenedTasks");
if ($user->rights->projet->all->lire) $response->url = DOL_URL_ROOT.'/projet/tasks/list.php?mainmenu=project';
else $response->url = DOL_URL_ROOT.'/projet/tasks/list.php?mode=mine&mainmenu=project';
- $response->img = img_object($langs->trans("Tasks"),"task");
+ $response->img = img_object('',"task");
// This assignment in condition is not a bug. It allows walking the results.
while ($obj=$this->db->fetch_object($resql))
diff --git a/htdocs/public/cron/cron_run_jobs.php b/htdocs/public/cron/cron_run_jobs.php
index fc8e15aeed6..a7d3d4b3fcd 100644
--- a/htdocs/public/cron/cron_run_jobs.php
+++ b/htdocs/public/cron/cron_run_jobs.php
@@ -111,7 +111,7 @@ if (! empty($id))
$filter['t.rowid']=$id;
}
-$result = $object->fetch_all('DESC','t.rowid', 0, 0, 1, $filter);
+$result = $object->fetch_all('DESC','t.rowid', 0, 0, 1, $filter, 0);
if ($result<0)
{
echo "Error: ".$cronjob->error;
diff --git a/htdocs/resource/element_resource.php b/htdocs/resource/element_resource.php
index a09e9d3db39..fbb75e021ff 100644
--- a/htdocs/resource/element_resource.php
+++ b/htdocs/resource/element_resource.php
@@ -197,7 +197,7 @@ else
$head=actions_prepare_head($act);
- dol_fiche_head($head, 'resources', $langs->trans("Action"),0,'action');
+ dol_fiche_head($head, 'resources', $langs->trans("Action"), -1, 'action');
$linkback =img_picto($langs->trans("BackToList"),'object_list','class="hideonsmartphone pictoactionview"');
$linkback.= '
'.$langs->trans("BackToList").'';
@@ -327,7 +327,7 @@ else
require_once DOL_DOCUMENT_ROOT . '/core/lib/company.lib.php';
$head = societe_prepare_head($socstatic);
- dol_fiche_head($head, 'resources', $langs->trans("ThirdParty"), 0, 'company');
+ dol_fiche_head($head, 'resources', $langs->trans("ThirdParty"), -1, 'company');
dol_banner_tab($socstatic, 'socid', '', ($user->societe_id ? 0 : 1), 'rowid', 'nom', '', '&element='.$element);
@@ -363,7 +363,7 @@ else
if (is_object($fichinter))
{
$head=fichinter_prepare_head($fichinter);
- dol_fiche_head($head, 'resource', $langs->trans("InterventionCard"),0,'intervention');
+ dol_fiche_head($head, 'resource', $langs->trans("InterventionCard"), -1, 'intervention');
// Intervention card
$linkback = '
'.$langs->trans("BackToList").'';
diff --git a/htdocs/supplier_proposal/class/supplier_proposal.class.php b/htdocs/supplier_proposal/class/supplier_proposal.class.php
index 0ec7710ee70..65efb97f824 100644
--- a/htdocs/supplier_proposal/class/supplier_proposal.class.php
+++ b/htdocs/supplier_proposal/class/supplier_proposal.class.php
@@ -2143,7 +2143,7 @@ class SupplierProposal extends CommonObject
$response->warning_delay = $delay_warning/60/60/24;
$response->label = $label;
$response->url = DOL_URL_ROOT.'/supplier_proposal/list.php?viewstatut='.$statut;
- $response->img = img_object($langs->trans("SupplierProposals"),"propal");
+ $response->img = img_object('',"propal");
// This assignment in condition is not a bug. It allows walking the results.
while ($obj=$this->db->fetch_object($resql))
diff --git a/htdocs/theme/eldy/graph-color.php b/htdocs/theme/eldy/graph-color.php
index 4346d007158..42989907747 100644
--- a/htdocs/theme/eldy/graph-color.php
+++ b/htdocs/theme/eldy/graph-color.php
@@ -28,7 +28,7 @@
global $theme_bordercolor, $theme_datacolor, $theme_bgcolor, $theme_bgcoloronglet;
$theme_bordercolor = array(235,235,224);
-$theme_datacolor = array(array(140,140,220), array(190,120,120), array(0,160,140), array(190,190,100), array(115,125,150), array(100,170,20), array(250,190,30), array(150,135,125), array(85,135,150), array(150,135,80), array(150,80,150));
+$theme_datacolor = array(array(120,140,220), array(190,120,120), array(0,160,140), array(190,190,100), array(115,125,150), array(100,170,20), array(250,190,30), array(150,135,125), array(85,135,150), array(150,135,80), array(150,80,150));
$theme_bgcolor = array(hexdec('F4'),hexdec('F4'),hexdec('F4'));
$theme_bgcoloronglet = array(hexdec('DE'),hexdec('E7'),hexdec('EC'));
diff --git a/htdocs/theme/eldy/style.css.php b/htdocs/theme/eldy/style.css.php
index babc2a190e2..8d3ea40cb14 100644
--- a/htdocs/theme/eldy/style.css.php
+++ b/htdocs/theme/eldy/style.css.php
@@ -585,7 +585,7 @@ div.myavailability {
padding-bottom: 4px;
}
.checkallactions {
- vertical-align: top;
+ vertical-align: text-bottom;
margin-top: 6px;
margin-left: 4px;
}
@@ -2463,7 +2463,7 @@ div.refidpadding {
}
div.refid {
font-weight: bold;
- color: #866;
+ color: #868;
font-size: 160%;
}
div.refidno {
@@ -2506,7 +2506,6 @@ div.pagination li {
div.pagination li.pagination a,
div.pagination li.pagination span {
padding: 6px 12px;
- margin-left: -1px;
line-height: 1.42857143;
color: #000;
text-decoration: none;
@@ -2917,6 +2916,7 @@ span.boxstatstext {
span.boxstatsindicator {
font-size: 130%;
font-weight: normal;
+ line-height: 29px;
}
span.dashboardlineindicator, span.dashboardlineindicatorlate {
font-size: 130%;
@@ -2930,17 +2930,32 @@ span.dashboardlineok {
}
span.dashboardlineko {
color: #FFF;
- font-size: 80%;
+ /*color: #8c4446 ! important;
+ padding-left: 1px;*/
+
+ font-size: 80%;
}
.dashboardlinelatecoin {
float: right;
position: relative;
text-align: right;
- top: -28px;
- padding: 1px 6px 1px 6px;
+ top: -24px;
+ padding: 1px 2px 1px 2px;
+ border-radius: .25em;
+
+ background-color: #af4705;
+ padding: 0px 5px 0px 5px;
+ top: -26px;
+}
+.imglatecoin {
+ padding: 1px 3px 1px 1px;
+ margin-left: 4px;
+ margin-right: 2px;
background-color: #8c4446;
color: #FFFFFF ! important;
border-radius: .25em;
+ display: inline-block;
+ vertical-align: middle;
}
.boxtable {
margin-bottom: 8px !important;
diff --git a/htdocs/theme/md/style.css.php b/htdocs/theme/md/style.css.php
index 4c1d32c31ad..d80630f0501 100644
--- a/htdocs/theme/md/style.css.php
+++ b/htdocs/theme/md/style.css.php
@@ -587,7 +587,7 @@ div.myavailability {
padding-bottom: 4px;
}
.checkallactions {
- vertical-align: top;
+ vertical-align: text-bottom;
margin-top: 6px;
margin-left: 4px;
}
@@ -2413,7 +2413,6 @@ div.pagination li {
div.pagination li.pagination a,
div.pagination li.pagination span {
padding: 6px 12px;
- margin-left: -1px;
line-height: 1.42857143;
color: #000;
text-decoration: none;
diff --git a/scripts/cron/cron_run_jobs.php b/scripts/cron/cron_run_jobs.php
index d60218fba22..4360e74cae5 100755
--- a/scripts/cron/cron_run_jobs.php
+++ b/scripts/cron/cron_run_jobs.php
@@ -128,7 +128,7 @@ if (! empty($id)) {
$filter['t.rowid']=$id;
}
-$result = $object->fetch_all('DESC','t.rowid', 0, 0, 1, $filter);
+$result = $object->fetch_all('DESC','t.rowid', 0, 0, 1, $filter, 0);
if ($result<0)
{
echo "Error: ".$object->error;
@@ -136,7 +136,7 @@ if ($result<0)
exit(-1);
}
-// TODO This sequence of code must be shared with code into cron_run_jobs.php php page.
+// TODO This sequence of code must be shared with code into public/cron/cron_run_jobs.php php page.
// current date
$now=dol_now();
diff --git a/htdocs/societe/class/companybankaccount.class.php b/htdocs/societe/class/companybankaccount.class.php
index ec770d628a0..72f237999f8 100644
--- a/htdocs/societe/class/companybankaccount.class.php
+++ b/htdocs/societe/class/companybankaccount.class.php
@@ -235,24 +235,49 @@ class CompanyBankAccount extends Account
/**
* Delete a rib from database
*
* @param User $user User deleting
* @return int <0 if KO, >0 if OK
*/
- function delete(User $user = null)
+ function delete(User $user = null, $notrigger=0)
{
global $conf;
+
+ $error = 0;
+
+ dol_syslog(get_class($this) . "::delete ".$this->id, LOG_DEBUG);
+
+ $this->db->begin();
+
+ if (! $error && ! $notrigger)
+ {
+ // Call trigger
+ $result=$this->call_trigger('COMAPNY_RIB_DELETE',$user);
+ if ($result < 0) $error++;
+ // End call triggers
+ }
- $sql = "DELETE FROM ".MAIN_DB_PREFIX."societe_rib";
- $sql.= " WHERE rowid = ".$this->id;
-
- dol_syslog(get_class($this)."::delete", LOG_DEBUG);
- $result = $this->db->query($sql);
- if ($result) {
+ if (! $error)
+ {
+ $sql = "DELETE FROM " . MAIN_DB_PREFIX . "societe_rib";
+ $sql .= " WHERE rowid = " . $this->id;
+
+ if (! $this->db->query($sql))
+ {
+ $error++;
+ $this->errors[]=$this->db->lasterror();
+ }
+ }
+
+ if (! $error)
+ {
+ $this->db->commit();
return 1;
}
- else {
- dol_print_error($this->db);
- return -1;
+ else
+ {
+ $this->db->rollback();
+ return -1*$error;
}
}
@@ -235,24 +235,49 @@ class CompanyBankAccount extends Account
* Delete a rib from database
*
- * @param User $user User deleting
- * @return int <0 if KO, >0 if OK
+ * @param User $user User deleting
+ * @param int $notrigger 1=Disable triggers
+ * @return int <0 if KO, >0 if OK
*/